[Checkins] SVN: five.customerize/trunk/setup.py bootstrap

Philipp von Weitershausen philikon at philikon.de
Sat Oct 28 18:09:58 EDT 2006


Log message for revision 70953:
  bootstrap
  

Changed:
  U   five.customerize/trunk/setup.py

-=-
Modified: five.customerize/trunk/setup.py
===================================================================
--- five.customerize/trunk/setup.py	2006-10-28 22:07:35 UTC (rev 70952)
+++ five.customerize/trunk/setup.py	2006-10-28 22:09:58 UTC (rev 70953)
@@ -11,39 +11,25 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Setup for zope.i18nmessageid package
 
 $Id$
 """
-
 import os
+from setuptools import setup, Extension
 
-try:
-    from setuptools import setup, Extension
-except ImportError, e:
-    from distutils.core import setup, Extension
-
-setup(name='zope.XXX',
-      version='1.0',
-      url='http://svn.zope.org/zope.XXX',
+setup(name='five.customerize',
+      version='0.1',
+      url='http://svn.zope.org/five.customerize',
       license='ZPL 2.1',
-      description='XXX',
+      description='TTW customization of template-based Zope 3 views',
       author='Zope Corporation and Contributors',
-      author_email='zope3-dev at zope.org',
+      author_email='z3-five at codespeak.net',
       long_description='',
       
-      packages=['zope', 'zope.XXX'],
+      packages=['five', 'five.customerize'],
       package_dir = {'': 'src'},
-
-##       ext_modules=[Extension("zope.XXX._zope_XXX",
-##                              [os.path.join('src', 'zope', 'XXX',
-##                                            "_zope_XXX.c")
-##                               ]),
-##                    ],
-
-      namespace_packages=['zope',],
-      tests_require = ['zope.testing'],
-      install_requires=['zope.deprecation'],
+      namespace_packages=['five',],
       include_package_data = True,
 
       zip_safe = False,
@@ -11,39 +11,25 @@
 #
 ##############################################################################
-"""Setup for zope.i18nmessageid package
+"""Setup for five.customerize package
 
 $Id$



More information about the Checkins mailing list